==> elgg-1.8.19.zip: elgg-1.8.19/mod/reportedcontent/languages/en.php <==
<?php
/**
 * Elgg reported content plugin language pack
 *
 * @package ElggReportedContent
 */

$english = array(

	'item:object:reported_content' => 'Reported items',
	'admin:administer_utilities:reportedcontent' => 'Reported content',
	'reportedcontent' => 'Reported content',
	'reportedcontent:this' => 'Report this',
	'reportedcontent:this:tooltip' => 'Report this page to an administrator',
	'reportedcontent:none' => 'There is no reported content',
	'reportedcontent:report' => 'Report to admin',
	'reportedcontent:title' => 'Page title',
	'reportedcontent:deleted' => 'The reported content has been deleted',
	'reportedcontent:notdeleted' => 'We were not able to delete that report',
	'reportedcontent:delete' => 'Delete report',
	'reportedcontent:areyousure' => 'Are you sure you want to delete?',
	'reportedcontent:archive' => 'Archive report',
	'reportedcontent:archived' => 'The report has been archived',
	'reportedcontent:visit' => 'Visit reported item',
	'reportedcontent:by' => 'Report by',
	'reportedcontent:objecttitle' => 'Page title',
	'reportedcontent:objecturl' => 'Page url',
	'reportedcontent:reason' => 'Reason for report',
	'reportedcontent:description' => 'Why are you reporting this?',
	'reportedcontent:address' => 'Location of the item',
	'reportedcontent:success' => 'Your report has been sent to the site admin',
	'reportedcontent:failing' => 'Your report could not be sent',
	'reportedcontent:report' => 'Report this',
	'reportedcontent:moreinfo' => 'More info',
	'reportedcontent:instructions' => 'This report will be sent to the administrators of this site for review.',
	'reportedcontent:numbertodisplay' => 'Number of reports to display',
	'reportedcontent:widget:description' => 'Display reported content',
	'reportedcontent:user' => 'Report user',

	'reportedcontent:failed' => 'Sorry, the attempt to report this content has failed.',
	'reportedcontent:notarchived' => 'We were not able to archive that report',
);

add_translation("en", $english);

==> elgg-1.9.2.zip: elgg-1.9.2/mod/reportedcontent/languages/en.php <==
<?php
return array(

	'item:object:reported_content' => 'Reported items',
	'admin:administer_utilities:reportedcontent' => 'Reported content',
	'reportedcontent' => 'Reported content',
	'reportedcontent:this' => 'Report this',
	'reportedcontent:this:tooltip' => 'Report this page to an administrator',
	'reportedcontent:none' => 'There is no reported content',
	'reportedcontent:report' => 'Report to admin',
	'reportedcontent:deleted' => 'The reported content has been deleted',
	'reportedcontent:notdeleted' => 'We were not able to delete that report',
	'reportedcontent:delete' => 'Delete report',
	'reportedcontent:areyousure' => 'Are you sure you want to delete?',
	'reportedcontent:archive' => 'Archive report',
	'reportedcontent:archived' => 'The report has been archived',
	'reportedcontent:visit' => 'Visit reported item',
	'reportedcontent:by' => 'Report by',
	'reportedcontent:objecttitle' => 'Page title',
	'reportedcontent:objecturl' => 'Page url',
	'reportedcontent:reason' => 'Reason for report',
	'reportedcontent:description' => 'Why are you reporting this?',
	'reportedcontent:address' => 'Location of the item',
	'reportedcontent:success' => 'Your report has been sent to the site admin',
	'reportedcontent:failing' => 'Your report could not be sent',
	'reportedcontent:report' => 'Report this',
	'reportedcontent:instructions' => 'This report will be sent to the administrators of this site for review.',
	'reportedcontent:numbertodisplay' => 'Number of reports to display',
	'reportedcontent:widget:description' => 'Display reported content',
	'reportedcontent:user' => 'Report user',

	'reportedcontent:failed' => 'Sorry, the attempt to report this content has failed.',
	'reportedcontent:notarchived' => 'We were not able to archive that report',
);
